# Readmission Prediction

This folder contains tasks for predicting hospital readmission within some time-frame post discharge. This is
a common and actionable task in the U.S. healthcare system in particular due to the financial penalties
imposed on hospitals for admission of patients who are readmitted within a certain time-frame post discharge.
We omit "ICU" readmission as this is a much less meaningful task in the context of most health-care systems,
as there do not exist (to the best of our knowledge) similar financial penalties for ICU readmission.

Many papers have examined readmission prediction (though not necessarily with the precise configuration
contained herein), such as the below:
TODO: Add references
